@@ -53,11 +53,14 @@ class ViewWrapper(object):
                 msg = 'Exception in %s.%s: %s' % (
                     self.view.__module__, self.view.__name__, e)
                 raise cls(msg), None, trace
-            except:
+            except Exception:
                 raise e
         raise ImproperlyConfigured('%s.%s does not define a view function or '
             'class.' % (self.view.__module__, self.view.__name__))
 
+    def __getattr__(self, name):
+        return getattr(self.view, name)
+
 
 class LazyViewWrapper(ViewWrapper):
     """
